@@ -219,23 +219,6 @@ inline bool is_modified(const std::map<size_t,std::string>& mod, int c)
   return false;
 }
 
-inline bool supports_modifier(const char *signature, int c)
-{
-  const char *escapes = std::strchr(signature, ':');
-  if (escapes == NULL)
-    return false;
-  const char *s = std::strchr(signature, c);
-  return s && s < escapes;
-}
-
-inline bool supports_escape(const char *signature, int escape)
-{
-  if (!signature)
-    return false;
-  const char *escapes = std::strchr(signature, ':');
-  return std::strchr(escapes != NULL ? escapes : signature, escape) != NULL;
-}
-
 inline int hex_or_octal_escape(const char *signature)
 {
   if (supports_escape(signature, 'x'))
@@ -432,6 +415,7 @@ static void insert_list(const char *pattern, size_t len, size_t& pos, convert_fl
 
 static void expand_list(const char *pattern, size_t len, size_t& loc, size_t& pos, convert_flag_type flags, const std::map<size_t,std::string>& mod, const char *signature, const char *par, const std::map<std::string,std::string> *macros, std::string& regex, bool& nl)
 {
+  size_t bls = pos - 1;
   bool invert = false;
   bool newline = false;
   if (pos + 1 < len && pattern[pos] == '^')
@@ -519,7 +503,7 @@ static void expand_list(const char *pattern, size_t len, size_t& loc, size_t& po
       break;
   }
   if (pos >= len || pattern[pos] != ']')
-    throw regex_error(regex_error::mismatched_brackets, pattern, loc);
+    throw regex_error(regex_error::mismatched_brackets, pattern, bls);
   if (invert && !newline && (flags & convert_flag::notnewline))
   {
     regex.append(&pattern[loc], pos - loc).append("\\n");
@@ -1040,7 +1024,7 @@ static void insert_list(const char *pattern, size_t len, size_t& pos, convert_fl
     }
   }
   if (pos >= len || pattern[pos] != ']')
-    throw regex_error(regex_error::mismatched_brackets, pattern, loc);
+    throw regex_error(regex_error::mismatched_brackets, pattern, loc - 1);
   if (negate)
     negate_list(flags, mod, ranges);
   extend_list(pattern, len, pos, flags, mod, ranges, macros);
@@ -1601,11 +1585,11 @@ std::string convert(const char *pattern, const char *signature, convert_flag_typ
           if (!is_modified(mod, 'u') || !supports_escape(signature, 'X'))
           {
 #ifndef WITH_UTF8_UNRESTRICTED
-            // translate \X to match any valid UTF-8
-            regex.append(&pattern[loc], pos - loc - 1).append(par).append("[\\x00-\\xff]|[\\xc2-\\xdf][\\x80-\\xbf]|\\xe0[\\xa0-\\xbf][\\x80-\\xbf]|[\\xe1-\\xec][\\x80-\\xbf][\\x80-\\xbf]|\\xed[\\x80-\\x9f][\\x80-\\xbf]|[\\xee\\xef][\\x80-\\xbf][\\x80-\\xbf]|\\xf0[\\x90-\\xbf][\\x80-\\xbf][\\x80-\\xbf]|[\\xf1-\\xf3][\\x80-\\xbf][\\x80-\\xbf][\\x80-\\xbf]|\\xf4[\\x80-\\x8f][\\x80-\\xbf][\\x80-\\xbf]").push_back(')');
+            // translate \X to match any valid UTF-8 even beyond
+            regex.append(&pattern[loc], pos - loc - 1).append(par).append("[\\x00-\\x7f]|[\\xc2-\\xdf][\\x80-\\xbf]|\\xe0[\\xa0-\\xbf][\\x80-\\xbf]|[\\xe1-\\xec][\\x80-\\xbf][\\x80-\\xbf]|\\xed[\\x80-\\x9f][\\x80-\\xbf]|[\\xee\\xef][\\x80-\\xbf][\\x80-\\xbf]|\\xf0[\\x90-\\xbf][\\x80-\\xbf][\\x80-\\xbf]|[\\xf1-\\xf3][\\x80-\\xbf][\\x80-\\xbf][\\x80-\\xbf]|\\xf4[\\x80-\\x8f][\\x80-\\xbf][\\x80-\\xbf]").push_back(')');
 #else
-            // translate \X to match any UTF-8 encoding, including malformed UTF-8 with overruns
-            regex.append(&pattern[loc], pos - loc - 1).append(par).append("[\\x00-\\xff]|[\\xc0-\\xff][\\x80-\\xbf]+").push_back(')');
+            // translate \X to match any valid UTF-8 encoding (including overruns)
+            regex.append(&pattern[loc], pos - loc - 1).append(par).append("[\\x00-\\x7f]|[\\xc2-\\xf4][\\x80-\\xbf]+").push_back(')');
 #endif
             loc = pos + 1;
           }
@@ -2022,6 +2006,7 @@ std::string convert(const char *pattern, const char *signature, convert_flag_typ
               throw regex_error(regex_error::invalid_repeat, pattern, pos);
             char *s;
             size_t n = static_cast<size_t>(std::strtoul(&pattern[pos], &s, 10));
+            size_t brc = pos - 1;
             pos = s - pattern;
             if (pos + 1 < len && pattern[pos] == ',')
             {
@@ -2048,7 +2033,7 @@ std::string convert(const char *pattern, const char *signature, convert_flag_typ
               if (pos + 1 < len)
                 throw regex_error(regex_error::invalid_repeat, pattern, pos);
               else
-                throw regex_error(regex_error::mismatched_braces, pattern, pos);
+                throw regex_error(regex_error::mismatched_braces, pattern, brc);
             }
             if (pos + 1 < len && (pattern[pos + 1] == '?' || pattern[pos + 1] == '+') && !supports_escape(signature, pattern[pos + 1]))
               throw regex_error(regex_error::invalid_quantifier, pattern, pos + 1);
@@ -2099,11 +2084,22 @@ std::string convert(const char *pattern, const char *signature, convert_flag_typ
           }
           else if (!supports_escape(signature, 'p'))
           {
-            // \p is not supported: this indicates that . is non-Unicode
-            if (supports_modifier(signature, 's') || supports_escape(signature, '.'))
-              regex.append(&pattern[loc], pos - loc).append(par).append(".[\\x80-\\xbf]*)");
+            // \p is not supported: this indicates that . is matches as non-Unicode but we want to match Unicode
+            if ((flags & convert_flag::lex))
+            {
+              // lex . matches any byte (including invalid UTF-8) and any Unicode character e.g. in a catch-all-else rule
+              if (supports_modifier(signature, 's') || supports_escape(signature, '.'))
+                regex.append(&pattern[loc], pos - loc).append(par).append(".[\\x80-\\xbf]*)");
+              else
+                regex.append(&pattern[loc], pos - loc).append(par).append("[^\\n][\\x80-\\xbf]*)");
+            }
             else
-              regex.append(&pattern[loc], pos - loc).append(par).append("[^\\n][\\x80-\\xbf]*)");
+            {
+              if (is_modified(mod, 's'))
+                regex.append(&pattern[loc], pos - loc).append(par).append("[^\\x80-\\xbf][\\x80-\\xbf]*)");
+              else
+                regex.append(&pattern[loc], pos - loc).append(par).append("[^\\n\\x80-\\xbf][\\x80-\\xbf]*)");
+            }
             loc = pos + 1;
           }
         }
